@@ -1,5 +1,6 @@
 from emannotationschemas.schemas.synapse import SynapseSchema
 from emannotationschemas.schemas.synapse import PlasticSynapse
+from emannotationschemas.schemas.synapse import ValidSynapse
 from emannotationschemas.schemas.synapse import BuhmannSynapseSchema
 from emannotationschemas.schemas.synapse import BuhmannEcksteinSynapseSchema
 from emannotationschemas.schemas.synapse import NoCleftSynapse
@@ -40,7 +41,7 @@ from emannotationschemas.schemas.neuropil import FlyNeuropil
 from emannotationschemas.errors import UnknownAnnotationTypeException
 from emannotationschemas.flatten import create_flattened_schema
 
-__version__ = "3.8.4"
+__version__ = "4.1.0"
 
 type_mapping = {
     "synapse": SynapseSchema,
@@ -72,6 +73,7 @@ type_mapping = {
     "proofreading_boolstatus_user": ProofreadingBoolStatusUser,
     "fly_neuropil": FlyNeuropil,
     "reference_point": FlatSegmentationReferenceSinglePoint,
+    "reference_synapse_valid": ValidSynapse,
 }
 
 
